@@ -158,7 +158,7 @@ class icmOverview(icm.Cmnd):
         if actions[0] == "all":
             actions = ['moduleDescription', 'moduleUsage', 'moduleStatus']
         for each in actions:
-            print each
+            print(each)
             if interactive:
                 #print( str( __doc__ ) )  # This is the Summary: from the top doc-string
                 #version(interactive=True)
@@ -319,7 +319,7 @@ class examples(icm.Cmnd):
 
         configBaseDir = bxPlatformThis.pkgBase_configDir()
 
-        print configBaseDir
+        print(configBaseDir)
 
         bxPlatformConfig.examples_pkgInfoParsFull(
             configBaseDir=configBaseDir,
