@@ -159,7 +159,7 @@ This module is part of BISOS and its primary documentation is in  http://www.by-
             argChoices.pop(0)
             actions = argChoices
         for each in actions:
-            print each
+            print(each)
             if interactive:
                 #print( str( __doc__ ) )  # This is the Summary: from the top doc-string
                 #version(interactive=True)
